==> zio-aws-iotthingsgraph_3-5.17.153.3-sources.jar: zio/aws/iotthingsgraph/model/FlowExecutionSummary.scala <==
package zio.aws.iotthingsgraph.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.iotthingsgraph.model.primitives.{Timestamp, Urn, FlowExecutionId}
import java.time.Instant
import scala.jdk.CollectionConverters.*
final case class FlowExecutionSummary(
    flowExecutionId: Option[FlowExecutionId] = None,
    status: Option[zio.aws.iotthingsgraph.model.FlowExecutionStatus] = None,
    systemInstanceId: Option[Urn] = None,
    flowTemplateId: Option[Urn] = None,
    createdAt: Option[Timestamp] = None,
    updatedAt: Option[Timestamp] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.iotthingsgraph.model.FlowExecutionSummary = {
    import FlowExecutionSummary.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.iotthingsgraph.model.FlowExecutionSummary
      .builder()
      .optionallyWith(
        flowExecutionId.map(value =>
          FlowExecutionId.unwrap(value): java.lang.String
        )
      )(_.flowExecutionId)
      .optionallyWith(status.map(value => value.unwrap))(_.status)
      .optionallyWith(
        systemInstanceId.map(value => Urn.unwrap(value): java.lang.String)
      )(_.systemInstanceId)
      .optionallyWith(
        flowTemplateId.map(value => Urn.unwrap(value): java.lang.String)
      )(_.flowTemplateId)
      .optionallyWith(createdAt.map(value => Timestamp.unwrap(value): Instant))(
        _.createdAt
      )
      .optionallyWith(updatedAt.map(value => Timestamp.unwrap(value): Instant))(
        _.updatedAt
      )
      .build()
  }
  def asReadOnly: zio.aws.iotthingsgraph.model.FlowExecutionSummary.ReadOnly =
    zio.aws.iotthingsgraph.model.FlowExecutionSummary.wrap(buildAwsValue())
}
object FlowExecutionSummary {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.iotthingsgraph.model.FlowExecutionSummary
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.iotthingsgraph.model.FlowExecutionSummary =
      zio.aws.iotthingsgraph.model.FlowExecutionSummary(
        flowExecutionId.map(value => value),
        status.map(value => value),
        systemInstanceId.map(value => value),
        flowTemplateId.map(value => value),
        createdAt.map(value => value),
        updatedAt.map(value => value)
      )
    def flowExecutionId: Option[FlowExecutionId]
    def status: Option[zio.aws.iotthingsgraph.model.FlowExecutionStatus]
    def systemInstanceId: Option[Urn]
    def flowTemplateId: Option[Urn]
    def createdAt: Option[Timestamp]
    def updatedAt: Option[Timestamp]
    def getFlowExecutionId: ZIO[Any, AwsError, FlowExecutionId] =
      AwsError.unwrapOptionField("flowExecutionId", flowExecutionId)
    def getStatus
        : ZIO[Any, AwsError, zio.aws.iotthingsgraph.model.FlowExecutionStatus] =
      AwsError.unwrapOptionField("status", status)
    def getSystemInstanceId: ZIO[Any, AwsError, Urn] =
      AwsError.unwrapOptionField("systemInstanceId", systemInstanceId)
    def getFlowTemplateId: ZIO[Any, AwsError, Urn] =
      AwsError.unwrapOptionField("flowTemplateId", flowTemplateId)
    def getCreatedAt: ZIO[Any, AwsError, Timestamp] =
      AwsError.unwrapOptionField("createdAt", createdAt)
    def getUpdatedAt: ZIO[Any, AwsError, Timestamp] =
      AwsError.unwrapOptionField("updatedAt", updatedAt)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.iotthingsgraph.model.FlowExecutionSummary
  ) extends zio.aws.iotthingsgraph.model.FlowExecutionSummary.ReadOnly {
    override val flowExecutionId: Option[FlowExecutionId] = scala
      .Option(impl.flowExecutionId())
      .map(value =>
        zio.aws.iotthingsgraph.model.primitives.FlowExecutionId(value)
      )
    override val status
        : Option[zio.aws.iotthingsgraph.model.FlowExecutionStatus] = scala
      .Option(impl.status())
      .map(value =>
        zio.aws.iotthingsgraph.model.FlowExecutionStatus.wrap(value)
      )
    override val systemInstanceId: Option[Urn] = scala
      .Option(impl.systemInstanceId())
      .map(value => zio.aws.iotthingsgraph.model.primitives.Urn(value))
    override val flowTemplateId: Option[Urn] = scala
      .Option(impl.flowTemplateId())
      .map(value => zio.aws.iotthingsgraph.model.primitives.Urn(value))
    override val createdAt: Option[Timestamp] = scala
      .Option(impl.createdAt())
      .map(value => zio.aws.iotthingsgraph.model.primitives.Timestamp(value))
    override val updatedAt: Option[Timestamp] = scala
      .Option(impl.updatedAt())
      .map(value => zio.aws.iotthingsgraph.model.primitives.Timestamp(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.iotthingsgraph.model.FlowExecutionSummary
  ): zio.aws.iotthingsgraph.model.FlowExecutionSummary.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-iotthingsgraph_3-5.19.31.4-sources.jar: zio/aws/iotthingsgraph/model/FlowExecutionSummary.scala <==
package zio.aws.iotthingsgraph.model
import java.time.Instant
import zio.prelude.data.Optional
import zio.aws.iotthingsgraph.model.primitives.{Timestamp, Urn, FlowExecutionId}
import zio.aws.core.{AwsError, BuilderHelper}
import zio.ZIO
import scala.jdk.CollectionConverters.*
final case class FlowExecutionSummary(
    flowExecutionId: Optional[FlowExecutionId] = Optional.Absent,
    status: Optional[zio.aws.iotthingsgraph.model.FlowExecutionStatus] =
      Optional.Absent,
    systemInstanceId: Optional[Urn] = Optional.Absent,
    flowTemplateId: Optional[Urn] = Optional.Absent,
    createdAt: Optional[Timestamp] = Optional.Absent,
    updatedAt: Optional[Timestamp] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.iotthingsgraph.model.FlowExecutionSummary = {
    import FlowExecutionSummary.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.iotthingsgraph.model.FlowExecutionSummary
      .builder()
      .optionallyWith(
        flowExecutionId.map(value =>
          FlowExecutionId.unwrap(value): java.lang.String
        )
      )(_.flowExecutionId)
      .optionallyWith(status.map(value => value.unwrap))(_.status)
      .optionallyWith(
        systemInstanceId.map(value => Urn.unwrap(value): java.lang.String)
      )(_.systemInstanceId)
      .optionallyWith(
        flowTemplateId.map(value => Urn.unwrap(value): java.lang.String)
      )(_.flowTemplateId)
      .optionallyWith(createdAt.map(value => Timestamp.unwrap(value): Instant))(
        _.createdAt
      )
      .optionallyWith(updatedAt.map(value => Timestamp.unwrap(value): Instant))(
        _.updatedAt
      )
      .build()
  }
  def asReadOnly: zio.aws.iotthingsgraph.model.FlowExecutionSummary.ReadOnly =
    zio.aws.iotthingsgraph.model.FlowExecutionSummary.wrap(buildAwsValue())
}
object FlowExecutionSummary {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.iotthingsgraph.model.FlowExecutionSummary
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.iotthingsgraph.model.FlowExecutionSummary =
      zio.aws.iotthingsgraph.model.FlowExecutionSummary(
        flowExecutionId.map(value => value),
        status.map(value => value),
        systemInstanceId.map(value => value),
        flowTemplateId.map(value => value),
        createdAt.map(value => value),
        updatedAt.map(value => value)
      )
    def flowExecutionId: Optional[FlowExecutionId]
    def status: Optional[zio.aws.iotthingsgraph.model.FlowExecutionStatus]
    def systemInstanceId: Optional[Urn]
    def flowTemplateId: Optional[Urn]
    def createdAt: Optional[Timestamp]
    def updatedAt: Optional[Timestamp]
    def getFlowExecutionId: ZIO[Any, AwsError, FlowExecutionId] =
      AwsError.unwrapOptionField("flowExecutionId", flowExecutionId)
    def getStatus
        : ZIO[Any, AwsError, zio.aws.iotthingsgraph.model.FlowExecutionStatus] =
      AwsError.unwrapOptionField("status", status)
    def getSystemInstanceId: ZIO[Any, AwsError, Urn] =
      AwsError.unwrapOptionField("systemInstanceId", systemInstanceId)
    def getFlowTemplateId: ZIO[Any, AwsError, Urn] =
      AwsError.unwrapOptionField("flowTemplateId", flowTemplateId)
    def getCreatedAt: ZIO[Any, AwsError, Timestamp] =
      AwsError.unwrapOptionField("createdAt", createdAt)
    def getUpdatedAt: ZIO[Any, AwsError, Timestamp] =
      AwsError.unwrapOptionField("updatedAt", updatedAt)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.iotthingsgraph.model.FlowExecutionSummary
  ) extends zio.aws.iotthingsgraph.model.FlowExecutionSummary.ReadOnly {
    override val flowExecutionId: Optional[FlowExecutionId] =
      zio.aws.core.internal
        .optionalFromNullable(impl.flowExecutionId())
        .map(value =>
          zio.aws.iotthingsgraph.model.primitives.FlowExecutionId(value)
        )
    override val status
        : Optional[zio.aws.iotthingsgraph.model.FlowExecutionStatus] =
      zio.aws.core.internal
        .optionalFromNullable(impl.status())
        .map(value =>
          zio.aws.iotthingsgraph.model.FlowExecutionStatus.wrap(value)
        )
    override val systemInstanceId: Optional[Urn] = zio.aws.core.internal
      .optionalFromNullable(impl.systemInstanceId())
      .map(value => zio.aws.iotthingsgraph.model.primitives.Urn(value))
    override val flowTemplateId: Optional[Urn] = zio.aws.core.internal
      .optionalFromNullable(impl.flowTemplateId())
      .map(value => zio.aws.iotthingsgraph.model.primitives.Urn(value))
    override val createdAt: Optional[Timestamp] = zio.aws.core.internal
      .optionalFromNullable(impl.createdAt())
      .map(value => zio.aws.iotthingsgraph.model.primitives.Timestamp(value))
    override val updatedAt: Optional[Timestamp] = zio.aws.core.internal
      .optionalFromNullable(impl.updatedAt())
      .map(value => zio.aws.iotthingsgraph.model.primitives.Timestamp(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.iotthingsgraph.model.FlowExecutionSummary
  ): zio.aws.iotthingsgraph.model.FlowExecutionSummary.ReadOnly = new Wrapper(
    impl
  )
}
